@@ -14,7 +14,7 @@
 
 
 #ifndef COMMON_H
-#define COMMON_H	 1
+#define COMMON_H     1
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -29,62 +29,62 @@
 #include <math.h>
 
 /* General definitions for signal processing */
-#define KEY_BUFF_SIZE		 256 /* Keyboard buffer size */
+#define KEY_BUFF_SIZE        256 /* Keyboard buffer size */
 
 /* Number and size of labels for commands  */
-#define NUM_OF_LABELS		10
-#define LABEL_LENGTH		25
+#define NUM_OF_LABELS       10
+#define LABEL_LENGTH        25
 
 /* Size of char arrays (strings) for error messages etc */
-#define MESG_SIZE	128
+#define MESG_SIZE   128
 
 /* Signal Detector parameter definitions */
-#define ELEMENT_MAX			100	/* Defined max val of dot elements */
+#define ELEMENT_MAX         100 /* Defined max val of dot elements */
 
 /* Flag definitions */
-#define NO_CALLBACKS		0x00000001U	/* Don't respond to callback if needed */
-#define RECORD_QSO			0x00000002	/* Enable recording of QSO's */
-#define CAPITALIZE			0x00000004	/* Capitalize letters in Transmit */
-#define CAPTURE_SETUP		0x00000008	/* Sound Capture has been set-up  */
-#define PLAYBACK_SETUP		0x00000010	/* Sound Playback has been set-up */
-#define MIXER_SETUP			0x00000020	/* Sound Mixer has been set-up */
-#define TRANSMIT_MODE		0x00000040	/* xfhell is in Transmit mode  */
-#define RECEIVE_MODE		0x00000080	/* xfhell is in Receive mode   */
-#define TRANSMIT_MACRO		0x00000100	/* Start transmission of Macro */
-#define TRANSMIT_TAG		0x00000200	/* Transmit text of tag in macro */
-#define TRANSMIT_KEYBD		0x00000400	/* Transmission from Keyboard */
-#define SAVE_RECORD			0x00000800	/* Record was saved to file */
-#define ENABLE_SCOPE		0x00001000	/* Display signal strength 'scope */
-#define CLEAR_TX_WINDOW		0x00002000	/* Clear the Transmit window */
-#define CLEAR_RX_WINDOW		0x00004000	/* Clear the Receive window */
-#define AUTO_DESKEW			0x00008000	/* Enable automatic deskewing */
-#define TX2RX_LOOPBACK		0x00010000	/* Enable loopback from Tx to Rx */
-#define KEYBD_BUSY			0x00020000	/* Transmit from Keyboard */
-#define SAVE_PIXBUF			0x00040000	/* Save the Receive window pixbuf */
-#define ENABLE_CAT			0x00080000	/* Enable transceiver CAT */
-#define CAT_SETUP			0x00100000	/* Trcvr CAT setup OK  */
-#define ENABLE_RTS_DTR		0x01000000	/* Enable RTS/DTR control of PTT */
-#define ENABLE_DTR			0x02000000	/* Enable DTR control of PTT */
-#define RTS_DTR_SETUP		0x04000000	/* RTS control setup OK */
-#define MODE_FELDHELL		0x08000000	/* Select FeldHell mode */
-#define INITIALIZE_CAIRO	0x10000000	/* Initialize cairo lib */
-#define TCVR_SERIAL_TEST	0x20000000	/* Serial port is under test */
-#define NEW_BAUD_RATE		0x40000000	/* New baud rate selected by user */
+#define NO_CALLBACKS        0x00000001U /* Don't respond to callback if needed */
+#define RECORD_QSO          0x00000002  /* Enable recording of QSO's */
+#define CAPITALIZE          0x00000004  /* Capitalize letters in Transmit */
+#define CAPTURE_SETUP       0x00000008  /* Sound Capture has been set-up  */
+#define PLAYBACK_SETUP      0x00000010  /* Sound Playback has been set-up */
+#define MIXER_SETUP         0x00000020  /* Sound Mixer has been set-up */
+#define TRANSMIT_MODE       0x00000040  /* xfhell is in Transmit mode  */
+#define RECEIVE_MODE        0x00000080  /* xfhell is in Receive mode   */
+#define TRANSMIT_MACRO      0x00000100  /* Start transmission of Macro */
+#define TRANSMIT_TAG        0x00000200  /* Transmit text of tag in macro */
+#define TRANSMIT_KEYBD      0x00000400  /* Transmission from Keyboard */
+#define SAVE_RECORD         0x00000800  /* Record was saved to file */
+#define ENABLE_SCOPE        0x00001000  /* Display signal strength 'scope */
+#define CLEAR_TX_WINDOW     0x00002000  /* Clear the Transmit window */
+#define CLEAR_RX_WINDOW     0x00004000  /* Clear the Receive window */
+#define AUTO_DESKEW         0x00008000  /* Enable automatic deskewing */
+#define TX2RX_LOOPBACK      0x00010000  /* Enable loopback from Tx to Rx */
+#define KEYBD_BUSY          0x00020000  /* Transmit from Keyboard */
+#define SAVE_PIXBUF         0x00040000  /* Save the Receive window pixbuf */
+#define ENABLE_CAT          0x00080000  /* Enable transceiver CAT */
+#define CAT_SETUP           0x00100000  /* Trcvr CAT setup OK  */
+#define ENABLE_RTS_DTR      0x01000000  /* Enable RTS/DTR control of PTT */
+#define ENABLE_DTR          0x02000000  /* Enable DTR control of PTT */
+#define RTS_DTR_SETUP       0x04000000  /* RTS control setup OK */
+#define MODE_FELDHELL       0x08000000  /* Select FeldHell mode */
+#define INITIALIZE_CAIRO    0x10000000  /* Initialize cairo lib */
+#define TCVR_SERIAL_TEST    0x20000000  /* Serial port is under test */
+#define NEW_BAUD_RATE       0x40000000  /* New baud rate selected by user */
 
 /* Some character definitions */
-#define HT			0x09 /* Horizontal Tab  */
-#define CR			0x0d /* Carriage Return */
-#define LF			0x0a /* Line Feed       */
-#define BS			0x08 /* Back Space      */
-#define IDLE_CHAR	0x1f /* Idle character  */
+#define HT          0x09 /* Horizontal Tab  */
+#define CR          0x0d /* Carriage Return */
+#define LF          0x0a /* Line Feed       */
+#define BS          0x08 /* Back Space      */
+#define IDLE_CHAR   0x1f /* Idle character  */
 
 /* Return values */
-#define SUCCESS		0
-#define ERROR		1
+#define SUCCESS     0
+#define ERROR       1
 
 /* For Error Dialog */
-#define QUIT	TRUE
-#define OK		FALSE
+#define QUIT    TRUE
+#define OK      FALSE
 
 /*-------------------------------------------------------------------*/
 
@@ -92,13 +92,13 @@
 typedef struct
 {
   int
-	encoding,
-	dwidth_x,
-	dwidth_y,
-	bbx_w,
-	bbx_h,
-	bbx_x,
-	bbx_y;
+    encoding,
+    dwidth_x,
+    dwidth_y,
+    bbx_w,
+    bbx_h,
+    bbx_x,
+    bbx_y;
 
   unsigned int *bitmap;
 
@@ -114,9 +114,9 @@ typedef struct
   int fbb_w, fbb_h, fbb_x, fbb_y;
 
   int
-	first_glyph, /* First character in font file */
-	last_glyph,  /* Last character in font file  */
-	num_glyphs;  /* Number of chars in font file */
+    first_glyph, /* First character in font file */
+    last_glyph,  /* Last character in font file  */
+    num_glyphs;  /* Number of chars in font file */
 
   glyph_data_t *glyph_data;
 
@@ -126,28 +126,28 @@ typedef struct
 typedef struct
 {
   char
-	snd_card[32], /* Sound card name */
-	pcm_dev[32],  /* PCM device name */
-	cap_src[32],  /* Capture source  */
-	cap_vol[32],  /* Capture volume control  */
-	mst_vol[32],  /* Master volume control   */
-	pcm_vol[32];  /* Playback volume control */
+    snd_card[32], /* Sound card name */
+    pcm_dev[32],  /* PCM device name */
+    cap_src[32],  /* Capture source  */
+    cap_vol[32],  /* Capture volume control  */
+    mst_vol[32],  /* Master volume control   */
+    pcm_vol[32];  /* Playback volume control */
 
   int
-	channel,	/* ALSA "channel" for use in mixer setup */
-	num_chn,	/* Number of audio channels (2=stereo, 1=mono) */
-	use_chn,	/* Channel in use (frontleft=0, frontright=1 etc) */
-	cap_lev,	/* Recording/Capture level */
-	pbk_lev,	/* Playback (volume) level */
-	tx_output,  /* Tx power output level */
-	dsp_rate;	/* DSP rate (speed) samples/sec */
+    channel,    /* ALSA "channel" for use in mixer setup */
+    num_chn,    /* Number of audio channels (2=stereo, 1=mono) */
+    use_chn,    /* Channel in use (frontleft=0, frontright=1 etc) */
+    cap_lev,    /* Recording/Capture level */
+    pbk_lev,    /* Playback (volume) level */
+    tx_output,  /* Tx power output level */
+    dsp_rate;   /* DSP rate (speed) samples/sec */
 
   /* Transceiver type 1=FT847 2=FT857 3=K2 4=K3 0=NONE */
   int tcvr_type;
 
   char
-	cat_serial[32], /* CAT serial port */
-	rts_serial[32]; /* RTS/DTR serial port */
+    cat_serial[32], /* CAT serial port */
+    rts_serial[32]; /* RTS/DTR serial port */
 
   gchar font_file[81]; /* Font file name */
 
@@ -155,45 +155,45 @@ typedef struct
   double baud_rate;
 
   int
-	wpm,				/* Morse encoder speed wpm */
-	wwrap,				/* Word wrap column number */
-	dot_size,			/* Receive dot height in pixels */
-	bitmap_height,		/* Receive bitmap height in pixels */
-	bitmap_width,		/* Receive bitmap width in pixels  */
-	rxarea_width,		/* Rx drawingarea width  */
-	rxarea_height,		/* Rx drawingarea height */
-	num_rows,			/* Number of character rows in Rx window */
-	samples_per_cycle,	/* Samples per cycle of audio freq. */
-	samples_per_dot,	/* Samples per Hell character half dot */
-	tone_freq,			/* Input tone (Rx BFO) frequency */
-	ifft_stride,			/* IFFT's stride over input data  */
-	center_line,		/* Position of tuning reference in ifft window */
-	txbuff_len,			/* Tx signal samples buffer size */
-	rxbuff_len;			/* Rx signal samples buffer size */
+    wpm,                /* Morse encoder speed wpm */
+    wwrap,              /* Word wrap column number */
+    dot_size,           /* Receive dot height in pixels */
+    bitmap_height,      /* Receive bitmap height in pixels */
+    bitmap_width,       /* Receive bitmap width in pixels  */
+    rxarea_width,       /* Rx drawingarea width  */
+    rxarea_height,      /* Rx drawingarea height */
+    num_rows,           /* Number of character rows in Rx window */
+    samples_per_cycle,  /* Samples per cycle of audio freq. */
+    samples_per_dot,    /* Samples per Hell character half dot */
+    tone_freq,          /* Input tone (Rx BFO) frequency */
+    ifft_stride,            /* IFFT's stride over input data  */
+    center_line,        /* Position of tuning reference in ifft window */
+    txbuff_len,         /* Tx signal samples buffer size */
+    rxbuff_len;         /* Rx signal samples buffer size */
 
   gboolean rev_video; /* Reverse "video" on transmit */
 
   FILE
-	*qso_record_fp,  /* File for recording QSO's */
-	*log_adif_fp,    /* File for ADIF QSO record */
-	*station_log_fp; /* File for station's log   */
+    *qso_record_fp,  /* File for recording QSO's */
+    *log_adif_fp,    /* File for ADIF QSO record */
+    *station_log_fp; /* File for station's log   */
 
   /* Local operator data */
   char
-	call[15],
-	name[13],
-	zone[15],
-	qth[13],
-	loc[7];
+    call[15],
+    name[13],
+    zone[15],
+    qth[13],
+    loc[7];
 
   /* Tx/Rx power, N.Fig, antennas */
   char
-	tx[12],
-	tx_power[10],
-	tx_ant[16],
-	rx[12],
-	rx_nfig[8],
-	rx_ant[16];
+    tx[12],
+    tx_power[10],
+    tx_ant[16],
+    rx[12],
+    rx_nfig[8],
+    rx_ant[16];
 
   /* CW message to send*/
   char cw_mesg[25];
@@ -211,19 +211,19 @@ typedef struct
 {
   /* QSO data */
   char
-	dx_call[15],  /* Remote (dx) station callsign */
-	dx_rst[4],    /* My RST report to Dx station  */
-	my_rst[4],    /* My RST report to Dx station  */
-	dx_name[13],  /* Remote station operator name */
-	dx_qth[13],   /* Remote station QTH loc. name */
-	dx_loc[7],    /* Remote station QTH locator   */
-	date[12],     /* Normal format QSO date  */
-	date_adif[9], /* QSO date in ADIF format */
-	time[6],      /* Normal format QSO time  */
-	time_adif[5], /* QSO time in ADIF format */
-	freq[14],     /* QSO operating frequency MHz */
-	mode[12],     /* Mode of operation */
-	via[13];      /* Via which path or relay Sat */
+    dx_call[15],  /* Remote (dx) station callsign */
+    dx_rst[4],    /* My RST report to Dx station  */
+    my_rst[4],    /* My RST report to Dx station  */
+    dx_name[13],  /* Remote station operator name */
+    dx_qth[13],   /* Remote station QTH loc. name */
+    dx_loc[7],    /* Remote station QTH locator   */
+    date[12],     /* Normal format QSO date  */
+    date_adif[9], /* QSO date in ADIF format */
+    time[6],      /* Normal format QSO time  */
+    time_adif[5], /* QSO time in ADIF format */
+    freq[14],     /* QSO operating frequency MHz */
+    mode[12],     /* Mode of operation */
+    via[13];      /* Via which path or relay Sat */
 
   /* Remarks on QSO */
   char remarks[46];
@@ -235,13 +235,13 @@ typedef struct
 typedef struct
 {
   GdkPixbuf *pixbuf; /* The GDK pixbuf */
-  guchar *pixels;	 /* Pointer to the pixels in above */
+  guchar *pixels;    /* Pointer to the pixels in above */
 
   int
-	rowstride,		 /* Row stride of pixbuf */
-	n_channels,		 /* Number of channels of pixbuf */
-	width,			 /* Width of pixbuf in pixels  */
-	height;			 /* Height of pixbuf in pixels */
+    rowstride,       /* Row stride of pixbuf */
+    n_channels,      /* Number of channels of pixbuf */
+    width,           /* Width of pixbuf in pixels  */
+    height;          /* Height of pixbuf in pixels */
 
 } pixbuf_data_t;
 
@@ -251,10 +251,10 @@ typedef struct
 typedef struct
 {
   int
-	comp_lev,	/* Compressor Level */
-	tx_power,	/* Tx Power Output  */
-	vfo_freq,	/* VFO A frequency  */
-	rig_mode;	/* Transceiver mode (usb|cw etc) */
+    comp_lev,   /* Compressor Level */
+    tx_power,   /* Tx Power Output  */
+    vfo_freq,   /* VFO A frequency  */
+    rig_mode;   /* Transceiver mode (usb|cw etc) */
 
 } tcvr_status_t;
 
@@ -356,6 +356,8 @@ void on_capitalize_letters_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_loopback_tx_to_rx_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_identify_in_cw_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_quit_activate(GtkMenuItem *menuitem, gpointer user_data);
+void on_save_dialog_destroy(GObject *object, gpointer user_data);
+void on_quit_dialog_destroy(GObject *object, gpointer user_data);
 void on_entry_ok_clicked(GtkButton *button, gpointer user_data);
 void on_cancel_quit_clicked(GtkButton *button, gpointer user_data);
 void on_quit_ok_clicked(GtkButton *button, gpointer user_data);
